@@ -14,8 +14,7 @@
    GNU Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public License
-   along with this library; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with this library; if not, see <https://www.gnu.org/licenses/>.  */
 
 /* Authors:   Callum McKenzie <callum@physics.otago.ac.nz> */
 
